Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(61)

Unified Diff: test/mjsunit/regress/regress-embedded-cons-string.js

Issue 23014007: Rename "parallel recompilation" to "concurrent recompilation". (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: test/mjsunit/regress/regress-embedded-cons-string.js
diff --git a/test/mjsunit/regress/regress-embedded-cons-string.js b/test/mjsunit/regress/regress-embedded-cons-string.js
index 6a63da2fde0c332b58df653682c514670e3d1570..58a0b1c86960fc93005390dda0c9a375ebd08335 100644
--- a/test/mjsunit/regress/regress-embedded-cons-string.js
+++ b/test/mjsunit/regress/regress-embedded-cons-string.js
@@ -27,27 +27,27 @@
// Flags: --fold-constants --nodead-code-elimination
// Flags: --expose-gc --allow-natives-syntax
-// Flags: --parallel-recompilation --parallel-recompilation-delay=300
+// Flags: --concurrent-recompilation --concurrent-recompilation-delay=300
-if (!%IsParallelRecompilationSupported()) {
- print("Parallel recompilation is disabled. Skipping this test.");
+if (!%IsConcurrentRecompilationSupported()) {
+ print("Concurrent recompilation is disabled. Skipping this test.");
quit();
}
function test(fun) {
fun();
fun();
// Mark for parallel optimization.
%OptimizeFunctionOnNextCall(fun, "parallel");
//Trigger optimization in the background.
fun();
//Tenure cons string.
gc();
// In the mean time, parallel recompiling is not complete yet.
assertUnoptimized(fun, "no sync");
// Parallel recompilation eventually finishes and embeds tenured cons string.
assertOptimized(fun, "sync");
- //Visit embedded cons string during mark compact.
+ // Visit embedded cons string during mark compact.
gc();
}
« no previous file with comments | « test/mjsunit/regress/regress-debug-deopt-while-recompile.js ('k') | test/mjsunit/regress/regress-opt-after-debug-deopt.js » ('j') | no next file with comments »
@@ -27,27 +27,27 @@
fun();
fun();
- // Mark for parallel optimization.
- %OptimizeFunctionOnNextCall(fun, "parallel");
+ // Mark for concurrent optimization.
+ %OptimizeFunctionOnNextCall(fun, "concurrent");
//Trigger optimization in the background.
fun();
@@ -27,27 +27,27 @@
//Tenure cons string.
gc();
- // In the mean time, parallel recompiling is not complete yet.
+ // In the mean time, concurrent recompiling is not complete yet.
assertUnoptimized(fun, "no sync");
@@ -27,27 +27,27 @@
assertUnoptimized(fun, "no sync");
- // Parallel recompilation eventually finishes and embeds tenured cons string.
+ // Concurrent recompilation eventually finishes, embeds tenured cons string.
assertOptimized(fun, "sync");

Powered by Google App Engine
This is Rietveld 408576698